django_turnit.backends package
==============================

.. automodule:: django_turnit.backends
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

django_turnit.backends.base module
----------------------------------

.. automodule:: django_turnit.backends.base
    :members:
    :undoc-members:
    :show-inheritance:

django_turnit.backends.gs module
--------------------------------

.. automodule:: django_turnit.backends.gs
    :members:
    :undoc-members:
    :show-inheritance:

django_turnit.backends.pdftocairo module
----------------------------------------

.. automodule:: django_turnit.backends.pdftocairo
    :members:
    :undoc-members:
    :show-inheritance:

django_turnit.backends.poppler module
-------------------------------------

.. automodule:: django_turnit.backends.poppler
    :members:
    :undoc-members:
    :show-inheritance:


